@@ -79,7 +79,7 @@ impl Functions for super::Interpreter {
                     "ERROR CREATING FILE",
                     format!("echo {} > {}': {err}", args[1], args[0]),
                 ),
-                _ => {}
+                _ => {},
             }
         }
     }
@@ -91,7 +91,7 @@ impl Functions for super::Interpreter {
                     "ERROR WHILE CREATING DIRECTORY",
                     format!("An error occurred:\n'mkdir --parent {arg}': {err}"),
                 ),
-                _ => {}
+                _ => {},
             };
         }
     }
@@ -157,8 +157,8 @@ impl Functions for super::Interpreter {
             // doing a hashmap of stuff deleted and then a checker,
             // enough overhead & bottlenecks with the async hell
             // of the cycles & the interpreter
-            if let Ok(_) = is_file {
-                if is_file.unwrap() {
+            if let Ok(result) = is_file  {
+                if result {
                     if let Err(err) =
                         fs::copy(self.trim_spaces(&args[0]), self.trim_spaces(&args[1]))
                     {
@@ -174,7 +174,7 @@ impl Functions for super::Interpreter {
                         &dir::CopyOptions::new(),
                     ) {
                         self.raise_error(
-                            "ERROR WHILE COPYING DIR",                            
+                            "ERROR WHILE COPYING DIR",
                             format!("An error occurred:\n'cp -r --parents --copy-contents {} {}': {err}", args[0], args[1]),
                         );
                     };
@@ -184,7 +184,7 @@ impl Functions for super::Interpreter {
     }
     fn r#shell(&self, args: &Args) {
         for arg in args {
-            // Detirmine operating system and launch associated process
+            // Determine operating system and launch associated process
             #[cfg(windows)]
             {
                 // Windows' shell is powershell/pwsh
