@@ -38,8 +38,7 @@ impl Conditionals for super::Parser {
                                 literal_val1.content
                             ),
                         );
-                        Some(literal_val1)
-                    }
+                    },
                     _ => Some(literal_val1),
                 };
             } else if let None = self.oper {
@@ -52,8 +51,7 @@ impl Conditionals for super::Parser {
                             "UNEXPECTED TOKEN",
                             format!("Expected an operator, got {}", token.content),
                         );
-                        Some(CondOperator::from_name(&token.tok_type))
-                    }
+                    },
                     CondOperator::Re | CondOperator::Rn => {
                         if next_token.tok_type != "Rgx" && last_token.tok_type != "Rgx" {
                             self.raise_parse_error(
@@ -62,13 +60,13 @@ impl Conditionals for super::Parser {
                                      "Expected a different operator, {} is only for regular expressions. Consider using other operator, like == or !=", token.content))
                         }
                         Some(CondOperator::from_name(&token.tok_type))
-                    }
+                    },
                     _ => {
                         if next_token.tok_type == "Rgx" || last_token.tok_type == "Rgx" {
                             self.raise_parse_error("UNEXPECTED TOKEN", format!("Expected a different operator, {} is not for regular expressions. Consider using other operator, like ~= or ~!", token.content))
                         }
                         Some(CondOperator::from_name(&token.tok_type))
-                    }
+                    },
                 }
             } else if let None = self.val2 {
                 println_on_debug!("  parsing val2, token {token}, next token {next_token}");
@@ -85,8 +83,7 @@ impl Conditionals for super::Parser {
                                 literal_val2.content
                             ),
                         );
-                        Some(literal_val2)
-                    }
+                    },
                     _ => Some(literal_val2),
                 };
             } else if let None = self.rela {
@@ -99,8 +96,7 @@ impl Conditionals for super::Parser {
                             "UNEXPECTED SYMBOL",
                             format!("Expected &&, || or {{, got {}", token.content),
                         );
-                        Some(CondRelationship::from_name(&token.tok_type))
-                    }
+                    },
                     _ => Some(CondRelationship::from_name(&token.tok_type)),
                 };
 
@@ -121,20 +117,16 @@ impl Conditionals for super::Parser {
         Conditional {
             val1: self.val1.clone().unwrap_or_else(|| {
                 self.raise_parse_error("EXPECTED VALUE", String::from("Found nothing"));
-                panic!()
-                }),
+            }),
             op: self.oper.clone().unwrap_or_else(|| {
                 self.raise_parse_error("EXPECTED OPERATOR", String::from("Found nothing"));
-                panic!()
-                }),
+            }),
             val2: self.val2.clone().unwrap_or_else(|| {
                 self.raise_parse_error("EXPECTED VALUE", String::from("Found nothing"));
-                panic!()
-                }),
+            }),
             next_conditional_relationship: self.rela.clone().unwrap_or_else(|| {
                 self.raise_parse_error("EXPECTED OPERATIONS", String::from("Found nothing"));
-                panic!()
-                }),
+            }),
             position: self.position.clone(),
         }
     }
